@@ -2,15 +2,10 @@ from shrub.v3.evg_build_variant import BuildVariant
 from shrub.v3.evg_command import EvgCommandType
 from shrub.v3.evg_task import EvgTask, EvgTaskRef
 
-from config_generator.components.funcs.find_cmake_latest import FindCMakeLatest
-
-from config_generator.etc.distros import find_large_distro
-from config_generator.etc.distros import make_distro_str
-from config_generator.etc.distros import compiler_to_vars
+from config_generator.etc.distros import compiler_to_vars, find_large_distro, make_distro_str
 from config_generator.etc.function import Function
 from config_generator.etc.utils import bash_exec
 
-
 TAG = 'std-matrix'
 
 
@@ -18,7 +13,6 @@ TAG = 'std-matrix'
 # fmt: off
 MATRIX = [
     ('rhel80',     'clang',    None, [99, 11, 17,   ]), # Clang 7.0
-    ('ubuntu2004', 'clang-10', None, [99, 11, 17, 23]), # Clang 10.0 (max: C2x)
     ('rhel84',     'clang',    None, [99, 11, 17, 23]), # Clang 11.0 (max: C2x)
     ('ubuntu2204', 'clang-12', None, [99, 11, 17, 23]), # Clang 12.0 (max: C2x)
     ('rhel90',     'clang',    None, [99, 11, 17, 23]), # Clang 13.0 (max: C2x)
@@ -28,18 +22,18 @@ MATRIX = [
     ('rhel94',     'clang',    None, [99, 11, 17, 23]), # Clang 17.0 (max: C2x)
     ('rhel95',     'clang',    None, [99, 11, 17, 23]), # Clang 18.0 (max: C23)
 
-    ('rhel7-latest', 'gcc',    None, [99, 11,       ]), # GCC 4.8 (max: C11)
-    ('rhel80',       'gcc',    None, [99, 11, 17,   ]), # GCC 8.2 (max: C17)
-    ('rhel84',       'gcc',    None, [99, 11, 17,   ]), # GCC 8.4 (max: C17)
-    ('ubuntu2004',   'gcc-9',  None, [99, 11, 17, 23]), # GCC 9.4 (max: C2x)
-    ('debian11',     'gcc-10', None, [99, 11, 17, 23]), # GCC 10.2 (max: C2x)
-    ('rhel90',       'gcc',    None, [99, 11, 17, 23]), # GCC 11.2 (max: C2x)
-    ('rhel92',       'gcc',    None, [99, 11, 17, 23]), # GCC 11.3 (max: C2x)
-    ('rhel94',       'gcc',    None, [99, 11, 17, 23]), # GCC 11.4 (max: C2x)
-    ('rhel95',       'gcc',    None, [99, 11, 17, 23]), # GCC 11.5 (max: C2x)
-    ('ubuntu2404',   'gcc-13', None, [99, 11, 17, 23]), # GCC 13.3 (max: C2x)
+    ('rhel7-latest',    'gcc',    None, [99, 11,       ]), # GCC 4.8 (max: C11)
+    ('rhel80',          'gcc',    None, [99, 11, 17,   ]), # GCC 8.2 (max: C17)
+    ('rhel84',          'gcc',    None, [99, 11, 17,   ]), # GCC 8.4 (max: C17)
+    ('debian11-latest', 'gcc-10', None, [99, 11, 17, 23]), # GCC 10.2 (max: C2x)
+    ('rhel90',          'gcc',    None, [99, 11, 17, 23]), # GCC 11.2 (max: C2x)
+    ('rhel92',          'gcc',    None, [99, 11, 17, 23]), # GCC 11.3 (max: C2x)
+    ('rhel94',          'gcc',    None, [99, 11, 17, 23]), # GCC 11.4 (max: C2x)
+    ('rhel95',          'gcc',    None, [99, 11, 17, 23]), # GCC 11.5 (max: C2x)
+    ('ubuntu2404',      'gcc-13', None, [99, 11, 17, 23]), # GCC 13.3 (max: C2x)
+
+    ('macos-14-arm64', 'clang', None, [99, 11, 17, 23]), # Apple Clang
 
-    ('windows-vsCurrent', 'vs2015x64', None, [99, 11,   ]), # Max: C11
     ('windows-vsCurrent', 'vs2017x64', None, [99, 11,   ]), # Max: C11
     ('windows-vsCurrent', 'vs2019x64', None, [99, 11, 17]), # Max: C17
     ('windows-vsCurrent', 'vs2022x64', None, [99, 11, 17]), # Max: C17
@@ -93,10 +87,7 @@ def tasks():
                     name=task_name,
                     run_on=distro.name,
                     tags=tags + [f'std-c{std}'],
-                    commands=[
-                        FindCMakeLatest.call(),
-                        StdCompile.call(vars=compile_vars | with_std)
-                    ],
+                    commands=[StdCompile.call(vars=compile_vars | with_std)],
                 )
             )
 
