@@ -20,10 +20,6 @@ class CheckMongocPublicHeaders(Function):
         ),
     ]
 
-    @classmethod
-    def call(cls, **kwargs):
-        return cls.default_call(**kwargs)
-
 
 def functions():
     return CheckMongocPublicHeaders.defn()
