@@ -11,10 +11,6 @@ class Backtrace(Function):
         ),
     ]
 
-    @classmethod
-    def call(cls, **kwargs):
-        return cls.default_call(**kwargs)
-
 
 def functions():
     return Backtrace.defn()
