@@ -1,6 +1,4 @@
-from shrub.v3.evg_command import EvgCommandType
-from shrub.v3.evg_command import expansions_update
-from shrub.v3.evg_command import git_get_project
+from shrub.v3.evg_command import EvgCommandType, expansions_update, git_get_project
 
 from config_generator.etc.function import Function
 from config_generator.etc.utils import bash_exec
@@ -14,7 +12,7 @@ class FetchSource(Function):
         bash_exec(
             command_type=command_type,
             working_dir='mongoc',
-            script='''\
+            script="""\
                 set -o errexit
                 set -o pipefail
                 if [ -n "${github_pr_number}" -o "${is_patch}" = "true" ]; then
@@ -23,19 +21,18 @@ class FetchSource(Function):
                     VERSION=latest
                 fi
                 echo "CURRENT_VERSION: $VERSION" > expansion.yml
-            '''
+            """,
         ),
-        expansions_update(command_type=command_type,
-                          file='mongoc/expansion.yml'),
+        expansions_update(command_type=command_type, file='mongoc/expansion.yml'),
         # Scripts may not be executable on Windows.
         bash_exec(
             command_type=EvgCommandType.SETUP,
             working_dir='mongoc',
-            script='''\
+            script="""\
                 for file in $(find .evergreen/scripts -type f); do
                     chmod +rx "$file" || exit
                 done
-            '''
+            """,
         ),
     ]
 
