@@ -15,10 +15,6 @@ class RunTests(Function):
         ),
     ]
 
-    @classmethod
-    def call(cls, **kwargs):
-        return cls.default_call(**kwargs)
-
 
 def functions():
     return RunTests.defn()
