@@ -1,7 +1,6 @@
 from shrub.v3.evg_build_variant import BuildVariant
 from shrub.v3.evg_task import EvgTaskRef
 
-
 TAG = 'sanitizers-matrix-tsan'
 
 
@@ -9,7 +8,7 @@ def variants():
     expansions = {
         'CFLAGS': '-fno-omit-frame-pointer',
         'CHECK_LOG': 'ON',
-        'EXTRA_CONFIGURE_FLAGS': '-DENABLE_EXTRA_ALIGNMENT=OFF -DENABLE_SHM_COUNTERS=OFF',
+        'EXTRA_CONFIGURE_FLAGS': '-DENABLE_SHM_COUNTERS=OFF',
         'SANITIZE': 'thread',
     }
 
