@@ -1,13 +1,11 @@
 from shrub.v3.evg_build_variant import BuildVariant
 from shrub.v3.evg_task import EvgTaskRef
 
-from config_generator.etc.function import merge_defns
 from config_generator.etc.compile import generate_compile_tasks
-
+from config_generator.etc.function import merge_defns
 from config_generator.etc.sasl.compile import CompileCommon
 from config_generator.etc.sasl.test import generate_test_tasks
 
-
 SSL = 'darwinssl'
 TAG = f'sasl-matrix-{SSL}'
 
@@ -15,17 +13,16 @@ TAG = f'sasl-matrix-{SSL}'
 # pylint: disable=line-too-long
 # fmt: off
 COMPILE_MATRIX = [
-    ('macos-14', 'clang', None, ['cyrus']),
-
-    ('macos-11-arm64', 'clang', None, ['cyrus']),
     ('macos-14-arm64', 'clang', None, ['cyrus']),
+    ('macos-14',       'clang', None, ['cyrus']),
 ]
 
 TEST_MATRIX = [
-    ('macos-14', 'clang', None, 'cyrus', ['auth'], ['server'], ['4.2', '4.4', '5.0']),
+    # Prefer macos-14-arm64 which is less resource-limited than macos-14. Provides 6.0+.
+    ('macos-14-arm64', 'clang', None, 'cyrus', ['auth'], ['replica'], ['6.0', '7.0', '8.0', 'latest']),
 
-    ('macos-11-arm64', 'clang', None, 'cyrus', ['auth'], ['server'], ['6.0', '7.0',                ]),
-    ('macos-14-arm64', 'clang', None, 'cyrus', ['auth'], ['server'], ['6.0', '7.0', '8.0', 'latest']),
+    # Pre-6.0 coverage. Resource-limited: use sparingly.
+    ('macos-14', 'clang', None, 'cyrus', ['auth'], ['replica'], ['4.2', '4.4', '5.0']),
 ]
 # fmt: on
 # pylint: enable=line-too-long
