@@ -1,12 +1,10 @@
 from shrub.v3.evg_build_variant import BuildVariant
 
-from config_generator.etc.utils import TaskRef
-from config_generator.etc.function import merge_defns
 from config_generator.etc.compile import generate_compile_tasks
-
+from config_generator.etc.function import merge_defns
 from config_generator.etc.sasl.compile import CompileCommon
 from config_generator.etc.sasl.test import generate_test_tasks
-
+from config_generator.etc.utils import TaskRef
 
 SSL = 'openssl'
 TAG = f'sasl-matrix-{SSL}'
@@ -17,30 +15,29 @@ TAG = f'sasl-matrix-{SSL}'
 COMPILE_MATRIX = [
     # For test matrix.
     ('amazon2023-arm64-latest-large-m8g', 'gcc', None, ['cyrus']),
-    ('rhel8-latest',      'gcc',        None, ['cyrus']),
-    ('rhel8-power',       'gcc',        None, ['cyrus']),
-    ('rhel8-zseries',     'gcc',        None, ['cyrus']),
-    ('ubuntu2004-arm64',  'gcc',        None, ['cyrus']),
-    ('windows-vsCurrent', 'vs2017x64',  None, ['cyrus']),
+    ('rhel8-latest',       'gcc',        None, ['cyrus']),
+    ('rhel8-arm64-latest', 'gcc',        None, ['cyrus']),
+    ('rhel8-power',        'gcc',        None, ['cyrus']),
+    ('rhel8-zseries',      'gcc',        None, ['cyrus']),
+    ('windows-vsCurrent',  'vs2017x64',  None, ['cyrus']),
 
     # For compile only.
-    ('debian11',   'gcc',      None, ['cyrus']),
-    ('debian12',   'gcc',      None, ['cyrus']),
-    ('rhel80',     'gcc',      None, ['cyrus']),
-    ('ubuntu2004', 'clang',    None, ['cyrus']),
-    ('ubuntu2204', 'gcc',      None, ['cyrus']),
-    ('ubuntu2204', 'clang-12', None, ['cyrus']),
-    ('ubuntu2404', 'gcc',      None, ['cyrus']),
-    ('ubuntu2404', 'clang-14', None, ['cyrus']),
+    ('debian11-latest', 'gcc',      None, ['cyrus']),
+    ('debian12-latest', 'gcc',      None, ['cyrus']),
+    ('rhel80',          'gcc',      None, ['cyrus']),
+    ('ubuntu2204',      'gcc',      None, ['cyrus']),
+    ('ubuntu2204',      'clang-12', None, ['cyrus']),
+    ('ubuntu2404',      'gcc',      None, ['cyrus']),
+    ('ubuntu2404',      'clang-14', None, ['cyrus']),
 ]
 
 TEST_MATRIX = [
-    ('rhel8-latest',  'gcc', None, 'cyrus', ['auth'], ['server'], ['4.2', '4.4', '5.0', '6.0', '7.0', '8.0', 'latest']),
-    ('rhel8-power',   'gcc', None, 'cyrus', ['auth'], ['server'], ['4.2', '4.4', '5.0', '6.0', '7.0', '8.0', 'latest']),
-    ('rhel8-zseries', 'gcc', None, 'cyrus', ['auth'], ['server'], [              '5.0', '6.0', '7.0', '8.0', 'latest']),
+    ('rhel8-latest',       'gcc', None, 'cyrus', ['auth'], ['server'], ['4.2', '4.4', '5.0', '6.0', '7.0', '8.0', 'latest']),
+    ('rhel8-arm64-latest', 'gcc', None, 'cyrus', ['auth'], ['server'], [       '4.4', '5.0', '6.0', '7.0', '8.0', 'latest']),
+    ('rhel8-power',        'gcc', None, 'cyrus', ['auth'], ['server'], ['4.2', '4.4', '5.0', '6.0', '7.0', '8.0', 'latest']),
+    ('rhel8-zseries',      'gcc', None, 'cyrus', ['auth'], ['server'], [              '5.0', '6.0', '7.0', '8.0', 'latest']),
 
-    ('ubuntu2004-arm64',  'gcc',       None, 'cyrus', ['auth'], ['server'], ['4.4', '5.0', '6.0', '7.0', '8.0', 'latest']),
-    ('windows-vsCurrent', 'vs2017x64', None, 'cyrus', ['auth'], ['server'], [       'latest']),
+    ('windows-vsCurrent',  'vs2017x64', None, 'cyrus', ['auth'], ['server'], ['latest']),
 
     # Test with Graviton processor:
     ('amazon2023-arm64-latest-large-m8g', 'gcc',  None, 'cyrus', ['auth'], ['server', 'replica', 'sharded'], ['latest']),
@@ -79,7 +76,7 @@ def tasks():
 
     # PowerPC and zSeries are limited resources.
     for task in res:
-        if any(pattern in task.run_on for pattern in ["power", "zseries"]):
+        if any(pattern in task.run_on for pattern in ['power', 'zseries']):
             task.patchable = False
 
     return res
@@ -92,11 +89,11 @@ def variants():
 
     # PowerPC and zSeries are limited resources.
     for task in TASKS:
-        if any(pattern in task.run_on for pattern in ["power", "zseries"]):
+        if any(pattern in task.run_on for pattern in ['power', 'zseries']):
             tasks.append(
                 TaskRef(
                     name=task.name,
-                    batchtime=1440,   # 1 day
+                    batchtime=1440,  # 1 day
                 )
             )
         else:
