@@ -1,11 +1,9 @@
 from typing import ClassVar
 
-from shrub.v3.evg_command import EvgCommand
-from shrub.v3.evg_command import EvgCommandType
-
-from config_generator.etc.utils import bash_exec
+from shrub.v3.evg_command import EvgCommand, EvgCommandType
 
 from config_generator.etc.function import Function
+from config_generator.etc.utils import bash_exec
 
 
 class CompileCommon(Function):
