@@ -39,22 +39,21 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from __future__ import unicode_literals, division, absolute_import, print_function
+from __future__ import absolute_import, division, print_function, unicode_literals
 
-import logging
 import base64
-import inspect
-import re
 import enum
+import inspect
+import logging
+import re
 import sys
 import textwrap
-from datetime import datetime, timezone, timedelta
-from typing import Callable, Tuple, Optional
+from datetime import datetime, timedelta, timezone
 
-from asn1crypto import x509, keys, core, ocsp
+from asn1crypto import core, keys, ocsp, x509
 from asn1crypto.ocsp import OCSPRequest, OCSPResponse
+from flask import Flask, Response, request
 from oscrypto import asymmetric
-from flask import Flask, request, Response
 
 __version__ = '0.10.2'
 __version_info__ = (0, 10, 2)
@@ -66,6 +65,7 @@ if sys.version_info < (3,):
 else:
     byte_cls = bytes
 
+
 def _pretty_message(string, *params):
     """
     Takes a multi-line string and does the following:
@@ -111,6 +111,7 @@ def _type_name(value):
         return cls.__name__
     return '%s.%s' % (cls.__module__, cls.__name__)
 
+
 def _writer(func):
     """
     Decorator for a custom writer, but a default reader
@@ -121,7 +122,6 @@ def _writer(func):
 
 
 class OCSPResponseBuilder(object):
-
     _response_status = None
     _certificate = None
     _certificate_status = None
@@ -184,12 +184,14 @@ class OCSPResponseBuilder(object):
         """
 
         if not isinstance(value, byte_cls):
-            raise TypeError(_pretty_message(
-                '''
-                nonce must be a byte string, not %s
-                ''',
-                _type_name(value)
-            ))
+            raise TypeError(
+                _pretty_message(
+                    """
+                    nonce must be a byte string, not %s
+                    """,
+                    _type_name(value),
+                )
+            )
 
         self._nonce = value
 
@@ -205,14 +207,16 @@ class OCSPResponseBuilder(object):
         if value is not None:
             is_oscrypto = isinstance(value, asymmetric.Certificate)
             if not is_oscrypto and not isinstance(value, x509.Certificate):
-                raise TypeError(_pretty_message(
-                    '''
-                    certificate_issuer must be an instance of
-                    asn1crypto.x509.Certificate or
-                    oscrypto.asymmetric.Certificate, not %s
-                    ''',
-                    _type_name(value)
-                ))
+                raise TypeError(
+                    _pretty_message(
+                        """
+                        certificate_issuer must be an instance of
+                        asn1crypto.x509.Certificate or
+                        oscrypto.asymmetric.Certificate, not %s
+                        """,
+                        _type_name(value),
+                    )
+                )
 
             if is_oscrypto:
                 value = value.asn1
@@ -228,12 +232,14 @@ class OCSPResponseBuilder(object):
         """
 
         if not isinstance(value, datetime):
-            raise TypeError(_pretty_message(
-                '''
-                next_update must be an instance of datetime.datetime, not %s
-                ''',
-                _type_name(value)
-            ))
+            raise TypeError(
+                _pretty_message(
+                    """
+                    next_update must be an instance of datetime.datetime, not %s
+                    """,
+                    _type_name(value),
+                )
+            )
 
         self._next_update = value
 
@@ -253,49 +259,49 @@ class OCSPResponseBuilder(object):
             An asn1crypto.ocsp.OCSPResponse object of the response
         """
         if self._response_status != 'successful':
-            return ocsp.OCSPResponse({
-                'response_status': self._response_status
-            })
+            return ocsp.OCSPResponse({'response_status': self._response_status})
 
         is_oscrypto = isinstance(responder_private_key, asymmetric.PrivateKey)
         if not isinstance(responder_private_key, keys.PrivateKeyInfo) and not is_oscrypto:
-            raise TypeError(_pretty_message(
-                '''
-                responder_private_key must be an instance ofthe c
-                asn1crypto.keys.PrivateKeyInfo or
-                oscrypto.asymmetric.PrivateKey, not %s
-                ''',
-                _type_name(responder_private_key)
-            ))
+            raise TypeError(
+                _pretty_message(
+                    """
+                    responder_private_key must be an instance ofthe c
+                    asn1crypto.keys.PrivateKeyInfo or
+                    oscrypto.asymmetric.PrivateKey, not %s
+                    """,
+                    _type_name(responder_private_key),
+                )
+            )
 
         cert_is_oscrypto = isinstance(responder_certificate, asymmetric.Certificate)
         if not isinstance(responder_certificate, x509.Certificate) and not cert_is_oscrypto:
-            raise TypeError(_pretty_message(
-                '''
-                responder_certificate must be an instance of
-                asn1crypto.x509.Certificate or
-                oscrypto.asymmetric.Certificate, not %s
-                ''',
-                _type_name(responder_certificate)
-            ))
+            raise TypeError(
+                _pretty_message(
+                    """
+                    responder_certificate must be an instance of
+                    asn1crypto.x509.Certificate or
+                    oscrypto.asymmetric.Certificate, not %s
+                    """,
+                    _type_name(responder_certificate),
+                )
+            )
 
         if cert_is_oscrypto:
             responder_certificate = responder_certificate.asn1
 
         if self._certificate_status_list is None:
-            raise ValueError(_pretty_message(
-                '''
-                certificate_status_list must be set if the response_status is
-                "successful"
-                '''
-            ))
+            raise ValueError(
+                _pretty_message(
+                    """
+                    certificate_status_list must be set if the response_status is
+                    "successful"
+                    """
+                )
+            )
 
         def _make_extension(name, value):
-            return {
-                'extn_id': name,
-                'critical': False,
-                'extn_value': value
-            }
+            return {'extn_id': name, 'critical': False, 'extn_value': value}
 
         responses = []
         for serial, status in self._certificate_status_list:
@@ -304,9 +310,7 @@ class OCSPResponseBuilder(object):
             for name, value in self._response_data_extensions.items():
                 response_data_extensions.append(_make_extension(name, value))
             if self._nonce:
-                response_data_extensions.append(
-                    _make_extension('nonce', self._nonce)
-                )
+                response_data_extensions.append(_make_extension('nonce', self._nonce))
 
             if not response_data_extensions:
                 response_data_extensions = None
@@ -318,12 +322,7 @@ class OCSPResponseBuilder(object):
                 single_response_extensions.append(
                     _make_extension(
                         'certificate_issuer',
-                        [
-                            x509.GeneralName(
-                                name='directory_name',
-                                value=self._certificate_issuer.subject
-                            )
-                        ]
+                        [x509.GeneralName(name='directory_name', value=self._certificate_issuer.subject)],
                     )
                 )
 
@@ -333,15 +332,9 @@ class OCSPResponseBuilder(object):
             responder_key_hash = getattr(responder_certificate.public_key, self._key_hash_algo)
 
             if status == 'good':
-                cert_status = ocsp.CertStatus(
-                    name='good',
-                    value=core.Null()
-                )
+                cert_status = ocsp.CertStatus(name='good', value=core.Null())
             elif status == 'unknown':
-                cert_status = ocsp.CertStatus(
-                    name='unknown',
-                    value=core.Null()
-                )
+                cert_status = ocsp.CertStatus(name='unknown', value=core.Null())
             else:
                 reason = status if status != 'revoked' else 'unspecified'
                 cert_status = ocsp.CertStatus(
@@ -349,7 +342,7 @@ class OCSPResponseBuilder(object):
                     value={
                         'revocation_time': self._revocation_date,
                         'revocation_reason': reason,
-                    }
+                    },
                 )
 
             issuer = self._certificate_issuer if self._certificate_issuer else responder_certificate
@@ -363,27 +356,27 @@ class OCSPResponseBuilder(object):
                 self._next_update = (self._this_update + timedelta(days=7)).replace(microsecond=0)
 
             response = {
-                    'cert_id': {
-                        'hash_algorithm': {
-                            'algorithm': self._key_hash_algo
-                        },
-                        'issuer_name_hash': getattr(issuer.subject, self._key_hash_algo),
-                        'issuer_key_hash': getattr(issuer.public_key, self._key_hash_algo),
-                        'serial_number': serial,
-                    },
-                    'cert_status': cert_status,
-                    'this_update': self._this_update,
-                    'next_update': self._next_update,
-                    'single_extensions': single_response_extensions
-                }
+                'cert_id': {
+                    'hash_algorithm': {'algorithm': self._key_hash_algo},
+                    'issuer_name_hash': getattr(issuer.subject, self._key_hash_algo),
+                    'issuer_key_hash': getattr(issuer.public_key, self._key_hash_algo),
+                    'serial_number': serial,
+                },
+                'cert_status': cert_status,
+                'this_update': self._this_update,
+                'next_update': self._next_update,
+                'single_extensions': single_response_extensions,
+            }
             responses.append(response)
 
-        response_data = ocsp.ResponseData({
-            'responder_id': ocsp.ResponderId(name='by_key', value=responder_key_hash),
-            'produced_at': produced_at,
-            'responses': responses,
-            'response_extensions': response_data_extensions
-        })
+        response_data = ocsp.ResponseData(
+            {
+                'responder_id': ocsp.ResponderId(name='by_key', value=responder_key_hash),
+                'produced_at': produced_at,
+                'responses': responses,
+                'response_extensions': response_data_extensions,
+            }
+        )
 
         signature_algo = responder_private_key.algorithm
         if signature_algo == 'ec':
@@ -403,24 +396,31 @@ class OCSPResponseBuilder(object):
         signature_bytes = sign_func(responder_private_key, response_data.dump(), self._hash_algo)
 
         certs = None
-        if self._certificate_issuer and getattr(self._certificate_issuer.public_key, self._key_hash_algo) != responder_key_hash:
+        if (
+            self._certificate_issuer
+            and getattr(self._certificate_issuer.public_key, self._key_hash_algo) != responder_key_hash
+        ):
             certs = [responder_certificate]
 
-        return ocsp.OCSPResponse({
-            'response_status': self._response_status,
-            'response_bytes': {
-                'response_type': 'basic_ocsp_response',
-                'response': {
-                    'tbs_response_data': response_data,
-                    'signature_algorithm': {'algorithm': signature_algorithm_id},
-                    'signature': signature_bytes,
-                    'certs': certs,
-                }
+        return ocsp.OCSPResponse(
+            {
+                'response_status': self._response_status,
+                'response_bytes': {
+                    'response_type': 'basic_ocsp_response',
+                    'response': {
+                        'tbs_response_data': response_data,
+                        'signature_algorithm': {'algorithm': signature_algorithm_id},
+                        'signature': signature_bytes,
+                        'certs': certs,
+                    },
+                },
             }
-        })
+        )
+
 
 # Enums
 
+
 class ResponseStatus(enum.Enum):
     successful = 'successful'
     malformed_request = 'malformed_request'
@@ -445,14 +445,14 @@ class CertificateStatus(enum.Enum):
 
 
 # API endpoints
-FAULT_REVOKED = "revoked"
-FAULT_UNKNOWN = "unknown"
+FAULT_REVOKED = 'revoked'
+FAULT_UNKNOWN = 'unknown'
 
 app = Flask(__name__)
-class OCSPResponder:
 
-    def __init__(self, issuer_cert: str, responder_cert: str, responder_key: str,
-                       fault: str, next_update_seconds: int):
+
+class OCSPResponder:
+    def __init__(self, issuer_cert: str, responder_cert: str, responder_key: str, fault: str, next_update_seconds: int):
         """
         Create a new OCSPResponder instance.
 
@@ -496,8 +496,8 @@ class OCSPResponder:
             return (CertificateStatus.revoked, time)
         elif self._fault == FAULT_UNKNOWN:
             return (CertificateStatus.unknown, None)
-        elif self._fault != None:
-            raise NotImplemented('Fault type could not be found')
+        elif self._fault is not None:
+            raise NotImplementedError('Fault type could not be found')
         return (CertificateStatus.good, time)
 
     def _build_ocsp_response(self, ocsp_request: OCSPRequest) -> OCSPResponse:
@@ -509,7 +509,7 @@ class OCSPResponder:
         request_list = tbs_request['request_list']
         if len(request_list) < 1:
             logger.warning('Received OCSP request with no requests')
-            raise NotImplemented('Empty requests not supported')
+            raise NotImplementedError('Empty requests not supported')
 
         single_request = request_list[0]  # TODO: Support more than one request
         req_cert = single_request['req_cert']
@@ -525,11 +525,13 @@ class OCSPResponder:
         certificate_status_list = [(serial, certificate_status.value)]
 
         # Build the response
-        builder = OCSPResponseBuilder(**{
-            'response_status': ResponseStatus.successful.value,
-            'certificate_status_list': certificate_status_list,
-            'revocation_date': revocation_date,
-        })
+        builder = OCSPResponseBuilder(
+            **{
+                'response_status': ResponseStatus.successful.value,
+                'certificate_status_list': certificate_status_list,
+                'revocation_date': revocation_date,
+            }
+        )
 
         # Parse extensions
         for extension in tbs_request['request_extensions']:
@@ -552,8 +554,7 @@ class OCSPResponder:
             # usually happen, according to RFC 6960 4.1.2), we should throw our
             # hands up in despair and run.
             if unknown is True and critical is True:
-                logger.warning('Could not parse unknown critical extension: %r',
-                        dict(extension.native))
+                logger.warning('Could not parse unknown critical extension: %r', dict(extension.native))
                 return self._fail(ResponseStatus.internal_error)
 
             # If it's an unknown non-critical extension, we can safely ignore it.
@@ -579,18 +580,28 @@ class OCSPResponder:
 
 responder = None
 
+
 def init_responder(issuer_cert: str, responder_cert: str, responder_key: str, fault: str, next_update_seconds: int):
     global responder
-    responder = OCSPResponder(issuer_cert=issuer_cert, responder_cert=responder_cert, responder_key=responder_key, fault=fault, next_update_seconds=next_update_seconds)
+    responder = OCSPResponder(
+        issuer_cert=issuer_cert,
+        responder_cert=responder_cert,
+        responder_key=responder_key,
+        fault=fault,
+        next_update_seconds=next_update_seconds,
+    )
+
 
 def init(port=8080, debug=False):
     logger.info('Launching %sserver on port %d', 'debug' if debug else '', port)
     app.run(port=port, debug=debug)
 
+
 @app.route('/', methods=['GET'])
 def _handle_root():
     return 'ocsp-responder'
 
+
 @app.route('/status/', defaults={'u_path': ''}, methods=['GET'])
 @app.route('/status/<path:u_path>', methods=['GET'])
 def _handle_get(u_path):
@@ -599,12 +610,13 @@ def _handle_get(u_path):
     An OCSP GET request contains the DER-in-base64 encoded OCSP request in the
     HTTP request URL.
     """
-    if "Host" not in request.headers:
-        raise ValueError ("Required 'Host' header not present")
+    if 'Host' not in request.headers:
+        raise ValueError("Required 'Host' header not present")
     der = base64.b64decode(u_path)
     ocsp_request = responder.parse_ocsp_request(der)
     return responder.build_http_response(ocsp_request)
 
+
 @app.route('/status', methods=['POST'])
 def _handle_post():
     global responder
@@ -612,7 +624,7 @@ def _handle_post():
     An OCSP POST request contains the DER encoded OCSP request in the HTTP
     request body.
     """
-    if "Host" not in request.headers:
-        raise ValueError ("Required 'Host' header not present")
+    if 'Host' not in request.headers:
+        raise ValueError("Required 'Host' header not present")
     ocsp_request = responder.parse_ocsp_request(request.data)
     return responder.build_http_response(ocsp_request)
