@@ -11,20 +11,17 @@ class Simple(BaseHTTPRequestHandler):
         self.send_response(http.HTTPStatus.OK)
         self.send_header('Content-type', 'text/html')
         self.end_headers()
-        self.wfile.write(
-            'Response to GET by simple HTTP server'.encode('utf-8'))
+        self.wfile.write('Response to GET by simple HTTP server'.encode('utf-8'))
 
     def do_POST(self):
         self.send_response(http.HTTPStatus.OK)
         self.send_header('Content-type', 'text/html')
         self.end_headers()
-        self.wfile.write(
-            'Response to POST by simple HTTP server'.encode('utf-8'))
+        self.wfile.write('Response to POST by simple HTTP server'.encode('utf-8'))
 
 
 def main():
-    HTTPServer(server_address=('', 18000),
-               RequestHandlerClass=Simple).serve_forever()
+    HTTPServer(server_address=('', 18000), RequestHandlerClass=Simple).serve_forever()
 
 
 if __name__ == '__main__':
