@@ -27,10 +27,10 @@
 #define MAX_RECURSION 100
 
 static double
-dtimeofday (void)
+dtimeofday(void)
 {
    struct timeval timeval;
-   bson_gettimeofday (&timeval);
+   bson_gettimeofday(&timeval);
    return (timeval.tv_sec + timeval.tv_usec * 0.000001);
 }
 
@@ -79,10 +79,10 @@ static bson_metrics_state_t initial_state = {0L,
 static bson_metrics_state_t state;
 
 static int
-compar_bson_type_metrics (const void *a, const void *b)
+compar_bson_type_metrics(const void *a, const void *b)
 {
-   const uint64_t a_count = ((bson_type_metrics_t *) a)->count;
-   const uint64_t b_count = ((bson_type_metrics_t *) b)->count;
+   const uint64_t a_count = ((bson_type_metrics_t *)a)->count;
+   const uint64_t b_count = ((bson_type_metrics_t *)b)->count;
    if (a_count == b_count) {
       return 0;
    }
@@ -93,18 +93,18 @@ compar_bson_type_metrics (const void *a, const void *b)
  * Forward declarations.
  */
 static bool
-bson_metrics_visit_array (const bson_iter_t *iter, const char *key, const bson_t *v_array, void *data);
+bson_metrics_visit_array(const bson_iter_t *iter, const char *key, const bson_t *v_array, void *data);
 static bool
-bson_metrics_visit_document (const bson_iter_t *iter, const char *key, const bson_t *v_document, void *data);
+bson_metrics_visit_document(const bson_iter_t *iter, const char *key, const bson_t *v_document, void *data);
 
 static bool
-bson_metrics_visit_utf8 (const bson_iter_t *iter, const char *key, size_t v_utf8_len, const char *v_utf8, void *data)
+bson_metrics_visit_utf8(const bson_iter_t *iter, const char *key, size_t v_utf8_len, const char *v_utf8, void *data)
 {
    bson_metrics_state_t *s = data;
 
-   BSON_UNUSED (iter);
-   BSON_UNUSED (key);
-   BSON_UNUSED (v_utf8);
+   BSON_UNUSED(iter);
+   BSON_UNUSED(key);
+   BSON_UNUSED(v_utf8);
 
    s->utf8_size_tally += v_utf8_len;
 
@@ -112,13 +112,13 @@ bson_metrics_visit_utf8 (const bson_iter_t *iter, const char *key, size_t v_utf8
 }
 
 static bool
-bson_metrics_visit_before (const bson_iter_t *iter, const char *key, void *data)
+bson_metrics_visit_before(const bson_iter_t *iter, const char *key, void *data)
 {
    bson_metrics_state_t *s = data;
    bson_type_t btype;
    ++s->element_count;
-   s->key_size_tally += strlen (key); /* TODO - filter out array keys(?) */
-   btype = bson_iter_type (iter);
+   s->key_size_tally += strlen(key); /* TODO - filter out array keys(?) */
+   btype = bson_iter_type(iter);
    ++s->bson_type_metrics[btype].count;
 
    return false;
@@ -151,22 +151,22 @@ static const bson_visitor_t bson_metrics_visitors = {
 };
 
 static bool
-bson_metrics_visit_document (const bson_iter_t *iter, const char *key, const bson_t *v_document, void *data)
+bson_metrics_visit_document(const bson_iter_t *iter, const char *key, const bson_t *v_document, void *data)
 {
    bson_metrics_state_t *s = data;
    bson_iter_t child;
 
-   BSON_UNUSED (iter);
-   BSON_UNUSED (key);
+   BSON_UNUSED(iter);
+   BSON_UNUSED(key);
 
    if (s->depth >= MAX_RECURSION) {
-      fprintf (stderr, "Invalid document, max recursion reached.\n");
+      fprintf(stderr, "Invalid document, max recursion reached.\n");
       return true;
    }
 
-   if (bson_iter_init (&child, v_document)) {
+   if (bson_iter_init(&child, v_document)) {
       s->depth++;
-      bson_iter_visit_all (&child, &bson_metrics_visitors, data);
+      bson_iter_visit_all(&child, &bson_metrics_visitors, data);
       s->depth--;
    }
 
@@ -174,22 +174,22 @@ bson_metrics_visit_document (const bson_iter_t *iter, const char *key, const bso
 }
 
 static bool
-bson_metrics_visit_array (const bson_iter_t *iter, const char *key, const bson_t *v_array, void *data)
+bson_metrics_visit_array(const bson_iter_t *iter, const char *key, const bson_t *v_array, void *data)
 {
    bson_metrics_state_t *s = data;
    bson_iter_t child;
 
-   BSON_UNUSED (iter);
-   BSON_UNUSED (key);
+   BSON_UNUSED(iter);
+   BSON_UNUSED(key);
 
    if (s->depth >= MAX_RECURSION) {
-      fprintf (stderr, "Invalid document, max recursion reached.\n");
+      fprintf(stderr, "Invalid document, max recursion reached.\n");
       return true;
    }
 
-   if (bson_iter_init (&child, v_array)) {
+   if (bson_iter_init(&child, v_array)) {
       s->depth++;
-      bson_iter_visit_all (&child, &bson_metrics_visitors, data);
+      bson_iter_visit_all(&child, &bson_metrics_visitors, data);
       s->depth--;
    }
 
@@ -197,22 +197,22 @@ bson_metrics_visit_array (const bson_iter_t *iter, const char *key, const bson_t
 }
 
 static void
-bson_metrics (const bson_t *bson, size_t *length, void *data)
+bson_metrics(const bson_t *bson, size_t *length, void *data)
 {
    bson_iter_t iter;
    bson_metrics_state_t *s = data;
 
-   BSON_UNUSED (length);
+   BSON_UNUSED(length);
 
    ++s->doc_count;
 
-   if (bson_iter_init (&iter, bson)) {
-      bson_iter_visit_all (&iter, &bson_metrics_visitors, data);
+   if (bson_iter_init(&iter, bson)) {
+      bson_iter_visit_all(&iter, &bson_metrics_visitors, data);
    }
 }
 
 int
-main (int argc, char *argv[])
+main(int argc, char *argv[])
 {
    bson_reader_t *reader;
    const bson_t *b;
@@ -227,83 +227,81 @@ main (int argc, char *argv[])
     * Print program usage if no arguments are provided.
     */
    if (argc == 1) {
-      fprintf (stderr, "usage: %s FILE...\n", argv[0]);
+      fprintf(stderr, "usage: %s FILE...\n", argv[0]);
       return 1;
    }
 
    /*
     * Process command line arguments expecting each to be a filename.
     */
-   printf ("[");
+   printf("[");
    for (i = 1; i < argc; i++) {
       if (i > 1)
-         printf (",");
+         printf(",");
       filename = argv[i];
 
       /*
        * Initialize a new reader for this file descriptor.
        */
-      if (!(reader = bson_reader_new_from_file (filename, &error))) {
-         fprintf (stderr, "Failed to open \"%s\": %s\n", filename, error.message);
+      if (!(reader = bson_reader_new_from_file(filename, &error))) {
+         fprintf(stderr, "Failed to open \"%s\": %s\n", filename, error.message);
          continue;
       }
 
       state = initial_state;
-      dtime_before = dtimeofday ();
+      dtime_before = dtimeofday();
       mark = 0;
-      while ((b = bson_reader_read (reader, NULL))) {
-         off_t pos = bson_reader_tell (reader);
-         state.doc_size_max = BSON_MAX (pos - mark, (off_t) state.doc_size_max);
+      while ((b = bson_reader_read(reader, NULL))) {
+         off_t pos = bson_reader_tell(reader);
+         state.doc_size_max = BSON_MAX(pos - mark, (off_t)state.doc_size_max);
          mark = pos;
-         bson_metrics (b, NULL, &state);
+         bson_metrics(b, NULL, &state);
       }
-      dtime_after = dtimeofday ();
-      dtime_delta = BSON_MAX (dtime_after - dtime_before, 0.000001);
+      dtime_after = dtimeofday();
+      dtime_delta = BSON_MAX(dtime_after - dtime_before, 0.000001);
       state.bson_type_metrics[BSON_TYPE_MAXKEY].description = "Max key";
       state.bson_type_metrics[BSON_TYPE_MINKEY].description = "Min key";
       aggregate_count =
          state.bson_type_metrics[BSON_TYPE_DOCUMENT].count + state.bson_type_metrics[BSON_TYPE_ARRAY].count;
-      qsort (state.bson_type_metrics, 256, sizeof (bson_type_metrics_t), compar_bson_type_metrics);
+      qsort(state.bson_type_metrics, 256, sizeof(bson_type_metrics_t), compar_bson_type_metrics);
 
-      printf ("\n  {\n");
-      printf ("    \"file\": \"%s\",\n", filename);
-      printf ("    \"secs\": %.2f,\n", dtime_delta);
-      printf ("    \"docs_per_sec\": %" PRIu64 ",\n", (uint64_t) floor (state.doc_count / dtime_delta));
-      printf ("    \"docs\": %" PRIu64 ",\n", state.doc_count);
-      printf ("    \"elements\": %" PRIu64 ",\n", state.element_count);
-      printf ("    \"elements_per_doc\": %" PRIu64 ",\n",
-              (uint64_t) floor ((double) state.element_count / (double) BSON_MAX (state.doc_count, 1)));
-      printf ("    \"aggregates\": %" PRIu64 ",\n", aggregate_count);
-      printf ("    \"aggregates_per_doc\": %" PRIu64 ",\n",
-              (uint64_t) floor ((double) aggregate_count / (double) BSON_MAX (state.doc_count, 1)));
-      printf (
-         "    \"degree\": %" PRIu64 ",\n",
-         (uint64_t) floor ((double) state.element_count / ((double) BSON_MAX (state.doc_count + aggregate_count, 1))));
-      printf ("    \"doc_size_max\": %" PRIu64 ",\n", state.doc_size_max);
-      printf ("    \"doc_size_average\": %" PRIu64 ",\n",
-              (uint64_t) floor ((double) bson_reader_tell (reader) / (double) BSON_MAX (state.doc_count, 1)));
-      printf ("    \"key_size_average\": %" PRIu64 ",\n",
-              (uint64_t) floor ((double) state.key_size_tally / (double) BSON_MAX (state.element_count, 1)));
-      printf ("    \"string_size_average\": %" PRIu64 ",\n",
-              (uint64_t) floor ((double) state.utf8_size_tally /
-                                (double) BSON_MAX (state.bson_type_metrics[BSON_TYPE_UTF8].count, 1)));
-      printf ("    \"percent_by_type\": {\n");
+      printf("\n  {\n");
+      printf("    \"file\": \"%s\",\n", filename);
+      printf("    \"secs\": %.2f,\n", dtime_delta);
+      printf("    \"docs_per_sec\": %" PRIu64 ",\n", (uint64_t)floor(state.doc_count / dtime_delta));
+      printf("    \"docs\": %" PRIu64 ",\n", state.doc_count);
+      printf("    \"elements\": %" PRIu64 ",\n", state.element_count);
+      printf("    \"elements_per_doc\": %" PRIu64 ",\n",
+             (uint64_t)floor((double)state.element_count / (double)BSON_MAX(state.doc_count, 1)));
+      printf("    \"aggregates\": %" PRIu64 ",\n", aggregate_count);
+      printf("    \"aggregates_per_doc\": %" PRIu64 ",\n",
+             (uint64_t)floor((double)aggregate_count / (double)BSON_MAX(state.doc_count, 1)));
+      printf("    \"degree\": %" PRIu64 ",\n",
+             (uint64_t)floor((double)state.element_count / ((double)BSON_MAX(state.doc_count + aggregate_count, 1))));
+      printf("    \"doc_size_max\": %" PRIu64 ",\n", state.doc_size_max);
+      printf("    \"doc_size_average\": %" PRIu64 ",\n",
+             (uint64_t)floor((double)bson_reader_tell(reader) / (double)BSON_MAX(state.doc_count, 1)));
+      printf("    \"key_size_average\": %" PRIu64 ",\n",
+             (uint64_t)floor((double)state.key_size_tally / (double)BSON_MAX(state.element_count, 1)));
+      printf("    \"string_size_average\": %" PRIu64 ",\n",
+             (uint64_t)floor((double)state.utf8_size_tally /
+                             (double)BSON_MAX(state.bson_type_metrics[BSON_TYPE_UTF8].count, 1)));
+      printf("    \"percent_by_type\": {\n");
       for (j = 0; state.bson_type_metrics[j].count > 0; j++) {
          bson_type_metrics_t bson_type_metrics = state.bson_type_metrics[j];
-         printf (
-            "      \"%s\": %" PRIu64 ",\n",
-            bson_type_metrics.description,
-            (uint64_t) floor ((double) bson_type_metrics.count * 100.0 / (double) BSON_MAX (state.element_count, 1)));
+         printf("      \"%s\": %" PRIu64 ",\n",
+                bson_type_metrics.description,
+                (uint64_t)floor((double)bson_type_metrics.count * 100.0 / (double)BSON_MAX(state.element_count, 1)));
       }
-      printf ("    }\n");
-      printf ("  }");
+      printf("    }\n");
+      printf("  }");
 
       /*
        * Cleanup after our reader, which closes the file descriptor.
        */
-      bson_reader_destroy (reader);
+      bson_reader_destroy(reader);
    }
-   printf ("\n]\n");
+   printf("\n]\n");
 
    return 0;
 }
