@@ -19,7 +19,10 @@
 #ifndef BSON_ERROR_PRIVATE_H
 #define BSON_ERROR_PRIVATE_H
 
-#include <bson/error.h>
+#include <bson/error.h> // IWYU pragma: export
+
+//
+
 #include <bson/macros.h>
 
 
@@ -27,9 +30,9 @@
 
 
 static BSON_INLINE void
-bson_set_error_category (bson_error_t *error, uint8_t category)
+bson_set_error_category(bson_error_t *error, uint8_t category)
 {
-   BSON_ASSERT_PARAM (error);
+   BSON_ASSERT_PARAM(error);
    error->reserved = category;
 }
 
