@@ -25,7 +25,7 @@
 
 
 static bool
-get_tok (const char *terminals, const char **ptr, int32_t *remaining, const char **out, int32_t *out_len)
+get_tok(const char *terminals, const char **ptr, int32_t *remaining, const char **out, int32_t *out_len)
 {
    const char *terminal;
    bool found_terminal = false;
@@ -55,12 +55,12 @@ get_tok (const char *terminals, const char **ptr, int32_t *remaining, const char
 }
 
 static bool
-digits_only (const char *str, int32_t len)
+digits_only(const char *str, int32_t len)
 {
    int i;
 
    for (i = 0; i < len; i++) {
-      if (!isdigit (str[i])) {
+      if (!isdigit(str[i])) {
          return false;
       }
    }
@@ -69,13 +69,13 @@ digits_only (const char *str, int32_t len)
 }
 
 static bool
-parse_num (const char *str, int32_t len, int32_t digits, int32_t min, int32_t max, int32_t *out)
+parse_num(const char *str, int32_t len, int32_t digits, int32_t min, int32_t max, int32_t *out)
 {
    int i;
    int magnitude = 1;
    int32_t value = 0;
 
-   if ((digits >= 0 && len != digits) || !digits_only (str, len)) {
+   if ((digits >= 0 && len != digits) || !digits_only(str, len)) {
       return false;
    }
 
@@ -93,7 +93,7 @@ parse_num (const char *str, int32_t len, int32_t digits, int32_t min, int32_t ma
 }
 
 bool
-_bson_iso8601_date_parse (const char *str, int32_t len, int64_t *out, bson_error_t *error)
+_bson_iso8601_date_parse(const char *str, int32_t len, int64_t *out, bson_error_t *error)
 {
    const char *ptr;
    int32_t remaining = len;
@@ -128,47 +128,47 @@ _bson_iso8601_date_parse (const char *str, int32_t len, int64_t *out, bson_error
    struct bson_tm posix_date = {0};
 
 #define DATE_PARSE_ERR(msg)                                                                                     \
-   bson_set_error (                                                                                             \
+   bson_set_error(                                                                                              \
       error, BSON_ERROR_JSON, BSON_JSON_ERROR_READ_INVALID_PARAM, "Could not parse \"%s\" as date: " msg, str); \
    return false
 
-#define DEFAULT_DATE_PARSE_ERR                                                 \
-   DATE_PARSE_ERR ("use ISO8601 format yyyy-mm-ddThh:mm plus timezone, either" \
-                   " \"Z\" or like \"+0500\" or like \"+05:00\"")
+#define DEFAULT_DATE_PARSE_ERR                                                \
+   DATE_PARSE_ERR("use ISO8601 format yyyy-mm-ddThh:mm plus timezone, either" \
+                  " \"Z\" or like \"+0500\" or like \"+05:00\"")
 
    ptr = str;
 
    /* we have to match at least yyyy-mm-ddThh:mm */
-   if (!(get_tok ("-", &ptr, &remaining, &year_ptr, &year_len) &&
-         get_tok ("-", &ptr, &remaining, &month_ptr, &month_len) &&
-         get_tok ("T", &ptr, &remaining, &day_ptr, &day_len) && get_tok (":", &ptr, &remaining, &hour_ptr, &hour_len) &&
-         get_tok (":+-Z", &ptr, &remaining, &min_ptr, &min_len))) {
+   if (!(get_tok("-", &ptr, &remaining, &year_ptr, &year_len) &&
+         get_tok("-", &ptr, &remaining, &month_ptr, &month_len) && get_tok("T", &ptr, &remaining, &day_ptr, &day_len) &&
+         get_tok(":", &ptr, &remaining, &hour_ptr, &hour_len) &&
+         get_tok(":+-Z", &ptr, &remaining, &min_ptr, &min_len))) {
       DEFAULT_DATE_PARSE_ERR;
    }
 
    /* if the minute has a ':' at the end look for seconds */
    if (min_ptr[min_len] == ':') {
       if (remaining < 2) {
-         DATE_PARSE_ERR ("reached end of date while looking for seconds");
+         DATE_PARSE_ERR("reached end of date while looking for seconds");
       }
 
-      get_tok (".+-Z", &ptr, &remaining, &sec_ptr, &sec_len);
+      get_tok(".+-Z", &ptr, &remaining, &sec_ptr, &sec_len);
 
       if (!sec_len) {
-         DATE_PARSE_ERR ("minute ends in \":\" seconds is required");
+         DATE_PARSE_ERR("minute ends in \":\" seconds is required");
       }
    }
 
    /* if we had a second and it is followed by a '.' look for milliseconds */
    if (sec_len && sec_ptr[sec_len] == '.') {
       if (remaining < 2) {
-         DATE_PARSE_ERR ("reached end of date while looking for milliseconds");
+         DATE_PARSE_ERR("reached end of date while looking for milliseconds");
       }
 
-      get_tok ("+-Z", &ptr, &remaining, &millis_ptr, &millis_len);
+      get_tok("+-Z", &ptr, &remaining, &millis_ptr, &millis_len);
 
       if (!millis_len) {
-         DATE_PARSE_ERR ("seconds ends in \".\", milliseconds is required");
+         DATE_PARSE_ERR("seconds ends in \".\", milliseconds is required");
       }
    }
 
@@ -176,36 +176,36 @@ _bson_iso8601_date_parse (const char *str, int32_t len, int64_t *out, bson_error
    ptr--;
    remaining++;
 
-   get_tok ("", &ptr, &remaining, &tz_ptr, &tz_len);
+   get_tok("", &ptr, &remaining, &tz_ptr, &tz_len);
 
-   if (!parse_num (year_ptr, year_len, 4, -9999, 9999, &year)) {
-      DATE_PARSE_ERR ("year must be an integer");
+   if (!parse_num(year_ptr, year_len, 4, -9999, 9999, &year)) {
+      DATE_PARSE_ERR("year must be an integer");
    }
 
    /* values are as in struct tm */
    year -= 1900;
 
-   if (!parse_num (month_ptr, month_len, 2, 1, 12, &month)) {
-      DATE_PARSE_ERR ("month must be an integer");
+   if (!parse_num(month_ptr, month_len, 2, 1, 12, &month)) {
+      DATE_PARSE_ERR("month must be an integer");
    }
 
    /* values are as in struct tm */
    month -= 1;
 
-   if (!parse_num (day_ptr, day_len, 2, 1, 31, &day)) {
-      DATE_PARSE_ERR ("day must be an integer");
+   if (!parse_num(day_ptr, day_len, 2, 1, 31, &day)) {
+      DATE_PARSE_ERR("day must be an integer");
    }
 
-   if (!parse_num (hour_ptr, hour_len, 2, 0, 23, &hour)) {
-      DATE_PARSE_ERR ("hour must be an integer");
+   if (!parse_num(hour_ptr, hour_len, 2, 0, 23, &hour)) {
+      DATE_PARSE_ERR("hour must be an integer");
    }
 
-   if (!parse_num (min_ptr, min_len, 2, 0, 59, &min)) {
-      DATE_PARSE_ERR ("minute must be an integer");
+   if (!parse_num(min_ptr, min_len, 2, 0, 59, &min)) {
+      DATE_PARSE_ERR("minute must be an integer");
    }
 
-   if (sec_len && !parse_num (sec_ptr, sec_len, 2, 0, 60, &sec)) {
-      DATE_PARSE_ERR ("seconds must be an integer");
+   if (sec_len && !parse_num(sec_ptr, sec_len, 2, 0, 60, &sec)) {
+      DATE_PARSE_ERR("seconds must be an integer");
    }
 
    if (tz_len > 0) {
@@ -215,18 +215,18 @@ _bson_iso8601_date_parse (const char *str, int32_t len, int64_t *out, bson_error
          int32_t tz_hour;
          int32_t tz_min;
 
-         if ((tz_len != 5 || !digits_only (tz_ptr + 1, 4)) &&
-             (tz_len != 6 || !digits_only (tz_ptr + 1, 2) || tz_ptr[3] != ':' || !digits_only (tz_ptr + 4, 2))) {
-            DATE_PARSE_ERR ("could not parse timezone");
+         if ((tz_len != 5 || !digits_only(tz_ptr + 1, 4)) &&
+             (tz_len != 6 || !digits_only(tz_ptr + 1, 2) || tz_ptr[3] != ':' || !digits_only(tz_ptr + 4, 2))) {
+            DATE_PARSE_ERR("could not parse timezone");
          }
 
-         if (!parse_num (tz_ptr + 1, 2, -1, -23, 23, &tz_hour)) {
-            DATE_PARSE_ERR ("timezone hour must be at most 23");
+         if (!parse_num(tz_ptr + 1, 2, -1, -23, 23, &tz_hour)) {
+            DATE_PARSE_ERR("timezone hour must be at most 23");
          }
 
          int32_t tz_min_offset = tz_ptr[3] == ':' ? 1 : 0;
-         if (!parse_num (tz_ptr + 3 + tz_min_offset, 2, -1, 0, 59, &tz_min)) {
-            DATE_PARSE_ERR ("timezone minute must be at most 59");
+         if (!parse_num(tz_ptr + 3 + tz_min_offset, 2, -1, 0, 59, &tz_min)) {
+            DATE_PARSE_ERR("timezone minute must be at most 59");
          }
 
          /* we inflect the meaning of a 'positive' timezone.  Those are hours
@@ -234,10 +234,10 @@ _bson_iso8601_date_parse (const char *str, int32_t len, int64_t *out, bson_error
          tz_adjustment = (tz_ptr[0] == '-' ? 1 : -1) * ((tz_min * 60) + (tz_hour * 60 * 60));
 
          if (!(tz_adjustment > -86400 && tz_adjustment < 86400)) {
-            DATE_PARSE_ERR ("timezone offset must be less than 24 hours");
+            DATE_PARSE_ERR("timezone offset must be less than 24 hours");
          }
       } else {
-         DATE_PARSE_ERR ("timezone is required");
+         DATE_PARSE_ERR("timezone is required");
       }
    }
 
@@ -246,8 +246,8 @@ _bson_iso8601_date_parse (const char *str, int32_t len, int64_t *out, bson_error
       int magnitude;
       millis = 0;
 
-      if (millis_len > 3 || !digits_only (millis_ptr, millis_len)) {
-         DATE_PARSE_ERR ("milliseconds must be an integer");
+      if (millis_len > 3 || !digits_only(millis_ptr, millis_len)) {
+         DATE_PARSE_ERR("milliseconds must be an integer");
       }
 
       for (i = 1, magnitude = 1; i <= millis_len; i++, magnitude *= 10) {
@@ -261,7 +261,7 @@ _bson_iso8601_date_parse (const char *str, int32_t len, int64_t *out, bson_error
       }
 
       if (millis < 0 || millis > 1000) {
-         DATE_PARSE_ERR ("milliseconds must be at least 0 and less than 1000");
+         DATE_PARSE_ERR("milliseconds must be at least 0 and less than 1000");
       }
    }
 
@@ -274,7 +274,7 @@ _bson_iso8601_date_parse (const char *str, int32_t len, int64_t *out, bson_error
    posix_date.tm_wday = 0;
    posix_date.tm_yday = 0;
 
-   millis = 1000 * _bson_timegm (&posix_date) + millis;
+   millis = 1000 * _bson_timegm(&posix_date) + millis;
    millis += tz_adjustment * 1000;
    *out = millis;
 
