@@ -19,9 +19,12 @@
 #ifndef MONGOC_CLIENT_POOL_PRIVATE_H
 #define MONGOC_CLIENT_POOL_PRIVATE_H
 
+#include <mongoc/mongoc-client-pool.h> // IWYU pragma: export
+
+//
+
 #include <mongoc/mongoc-topology-private.h>
 
-#include <mongoc/mongoc-client-pool.h>
 #include <mongoc/mongoc-topology-description.h>
 
 #include <bson/bson.h>
@@ -30,13 +33,13 @@ BSON_BEGIN_DECLS
 
 /* for tests */
 void
-_mongoc_client_pool_set_stream_initiator (mongoc_client_pool_t *pool, mongoc_stream_initiator_t si, void *user_data);
+_mongoc_client_pool_set_stream_initiator(mongoc_client_pool_t *pool, mongoc_stream_initiator_t si, void *user_data);
 size_t
-mongoc_client_pool_get_size (mongoc_client_pool_t *pool);
+mongoc_client_pool_get_size(mongoc_client_pool_t *pool);
 size_t
-mongoc_client_pool_num_pushed (mongoc_client_pool_t *pool);
+mongoc_client_pool_num_pushed(mongoc_client_pool_t *pool);
 mongoc_topology_t *
-_mongoc_client_pool_get_topology (mongoc_client_pool_t *pool);
+_mongoc_client_pool_get_topology(mongoc_client_pool_t *pool);
 
 BSON_END_DECLS
 
