@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-#include "mongoc-prelude.h"
+#include <mongoc/mongoc-prelude.h>
 
 #ifndef MONGOC_FLAGS_H
 #define MONGOC_FLAGS_H
@@ -25,23 +25,6 @@
 BSON_BEGIN_DECLS
 
 
-/**
- * mongoc_delete_flags_t:
- * @MONGOC_DELETE_NONE: Specify no delete flags.
- * @MONGOC_DELETE_SINGLE_REMOVE: Only remove the first document matching the
- *    document selector.
- *
- * This type is only for use with deprecated functions and should not be
- * used in new code. Use mongoc_remove_flags_t instead.
- *
- * #mongoc_delete_flags_t are used when performing a delete operation.
- */
-typedef enum {
-   MONGOC_DELETE_NONE = 0,
-   MONGOC_DELETE_SINGLE_REMOVE = 1 << 0,
-} mongoc_delete_flags_t;
-
-
 /**
  * mongoc_remove_flags_t:
  * @MONGOC_REMOVE_NONE: Specify no delete flags.
@@ -78,7 +61,7 @@ typedef enum {
  * @MONGOC_QUERY_NONE: No query flags supplied.
  * @MONGOC_QUERY_TAILABLE_CURSOR: Cursor will not be closed when the last
  *    data is retrieved. You can resume this cursor later.
- * @MONGOC_QUERY_SLAVE_OK: Allow query of replica slave.
+ * @MONGOC_QUERY_SECONDARY_OK: Allow query of secondaries in a replica set.
  * @MONGOC_QUERY_OPLOG_REPLAY: Used internally by Mongo.
  * @MONGOC_QUERY_NO_CURSOR_TIMEOUT: The server normally times out idle
  *    cursors after an inactivity period (10 minutes). This prevents that.
@@ -95,7 +78,7 @@ typedef enum {
 typedef enum {
    MONGOC_QUERY_NONE = 0,
    MONGOC_QUERY_TAILABLE_CURSOR = 1 << 1,
-   MONGOC_QUERY_SLAVE_OK = 1 << 2,
+   MONGOC_QUERY_SECONDARY_OK = 1 << 2,
    MONGOC_QUERY_OPLOG_REPLAY = 1 << 3,
    MONGOC_QUERY_NO_CURSOR_TIMEOUT = 1 << 4,
    MONGOC_QUERY_AWAIT_DATA = 1 << 5,
@@ -104,27 +87,6 @@ typedef enum {
 } mongoc_query_flags_t;
 
 
-/**
- * mongoc_reply_flags_t:
- * @MONGOC_REPLY_NONE: No flags set.
- * @MONGOC_REPLY_CURSOR_NOT_FOUND: Cursor was not found.
- * @MONGOC_REPLY_QUERY_FAILURE: Query failed, error document provided.
- * @MONGOC_REPLY_SHARD_CONFIG_STALE: Shard configuration is stale.
- * @MONGOC_REPLY_AWAIT_CAPABLE: Wait for data to be returned until timeout
- *    has passed. Used with %MONGOC_QUERY_TAILABLE_CURSOR.
- *
- * #mongoc_reply_flags_t contains flags supplied by the Mongo server in reply
- * to a request.
- */
-typedef enum {
-   MONGOC_REPLY_NONE = 0,
-   MONGOC_REPLY_CURSOR_NOT_FOUND = 1 << 0,
-   MONGOC_REPLY_QUERY_FAILURE = 1 << 1,
-   MONGOC_REPLY_SHARD_CONFIG_STALE = 1 << 2,
-   MONGOC_REPLY_AWAIT_CAPABLE = 1 << 3,
-} mongoc_reply_flags_t;
-
-
 /**
  * mongoc_update_flags_t:
  * @MONGOC_UPDATE_NONE: No update flags specified.
