@@ -19,6 +19,10 @@
 #ifndef MONGOC_GRIDFS_FILE_LIST_PRIVATE_H
 #define MONGOC_GRIDFS_FILE_LIST_PRIVATE_H
 
+#include <mongoc/mongoc-gridfs-file-list.h> // IWYU pragma: export
+
+//
+
 #include <mongoc/mongoc-cursor.h>
 #include <mongoc/mongoc-gridfs-file.h>
 #include <mongoc/mongoc-gridfs.h>
@@ -37,9 +41,9 @@ struct _mongoc_gridfs_file_list_t {
 
 
 mongoc_gridfs_file_list_t *
-_mongoc_gridfs_file_list_new (mongoc_gridfs_t *gridfs, const bson_t *query, uint32_t limit);
+_mongoc_gridfs_file_list_new(mongoc_gridfs_t *gridfs, const bson_t *query, uint32_t limit);
 mongoc_gridfs_file_list_t *
-_mongoc_gridfs_file_list_new_with_opts (mongoc_gridfs_t *gridfs, const bson_t *filter, const bson_t *opts);
+_mongoc_gridfs_file_list_new_with_opts(mongoc_gridfs_t *gridfs, const bson_t *filter, const bson_t *opts);
 
 
 BSON_END_DECLS
