@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 MongoDB Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,18 +14,16 @@
  * limitations under the License.
  */
 
+#include <mongoc/mongoc-prelude.h>
+
 #ifndef MONGOC_GRIDFS_FILE_LIST_H
 #define MONGOC_GRIDFS_FILE_LIST_H
 
-#if !defined(MONGOC_INSIDE) && !defined(MONGOC_COMPILATION)
-#error "Only <mongoc/mongoc.h> can be included directly."
-#endif
+#include <mongoc/mongoc-gridfs-file.h>
+#include <mongoc/mongoc-macros.h>
 
 #include <bson/bson.h>
 
-#include "mongoc/mongoc-macros.h"
-#include "mongoc/mongoc-gridfs-file.h"
-
 
 BSON_BEGIN_DECLS
 
@@ -33,13 +31,12 @@ BSON_BEGIN_DECLS
 typedef struct _mongoc_gridfs_file_list_t mongoc_gridfs_file_list_t;
 
 
-MONGOC_EXPORT (mongoc_gridfs_file_t *)
-mongoc_gridfs_file_list_next (mongoc_gridfs_file_list_t *list);
-MONGOC_EXPORT (void)
-mongoc_gridfs_file_list_destroy (mongoc_gridfs_file_list_t *list);
-MONGOC_EXPORT (bool)
-mongoc_gridfs_file_list_error (mongoc_gridfs_file_list_t *list,
-                               bson_error_t *error);
+MONGOC_EXPORT(mongoc_gridfs_file_t *)
+mongoc_gridfs_file_list_next(mongoc_gridfs_file_list_t *list) BSON_GNUC_WARN_UNUSED_RESULT;
+MONGOC_EXPORT(void)
+mongoc_gridfs_file_list_destroy(mongoc_gridfs_file_list_t *list);
+MONGOC_EXPORT(bool)
+mongoc_gridfs_file_list_error(mongoc_gridfs_file_list_t *list, bson_error_t *error);
 
 
 BSON_END_DECLS
