@@ -19,6 +19,10 @@
 #ifndef MONGOC_GRIDFS_PRIVATE_H
 #define MONGOC_GRIDFS_PRIVATE_H
 
+#include <mongoc/mongoc-gridfs.h> // IWYU pragma: export
+
+//
+
 #include <mongoc/mongoc-client.h>
 #include <mongoc/mongoc-read-prefs.h>
 #include <mongoc/mongoc-write-concern.h>
@@ -37,7 +41,7 @@ struct _mongoc_gridfs_t {
 
 
 mongoc_gridfs_t *
-_mongoc_gridfs_new (mongoc_client_t *client, const char *db, const char *prefix, bson_error_t *error);
+_mongoc_gridfs_new(mongoc_client_t *client, const char *db, const char *prefix, bson_error_t *error);
 
 
 BSON_END_DECLS
