@@ -47,32 +47,32 @@ static mongoc_log_func_t gLogFunc = mongoc_log_default_handler;
 bool gLogTrace = MONGOC_TRACE_ENABLED;
 static void *gLogData;
 
-static BSON_ONCE_FUN (_mongoc_ensure_mutex_once)
+static BSON_ONCE_FUN(_mongoc_ensure_mutex_once)
 {
-   bson_mutex_init (&gLogMutex);
+   bson_mutex_init(&gLogMutex);
 
    BSON_ONCE_RETURN;
 }
 
 void
-mongoc_log_set_handler (mongoc_log_func_t log_func, void *user_data)
+mongoc_log_set_handler(mongoc_log_func_t log_func, void *user_data)
 {
-   bson_once (&once, &_mongoc_ensure_mutex_once);
+   bson_once(&once, &_mongoc_ensure_mutex_once);
 
-   bson_mutex_lock (&gLogMutex);
+   bson_mutex_lock(&gLogMutex);
    gLogFunc = log_func;
    gLogData = user_data;
-   bson_mutex_unlock (&gLogMutex);
+   bson_mutex_unlock(&gLogMutex);
 }
 
 bool
-_mongoc_log_trace_is_enabled (void)
+_mongoc_log_trace_is_enabled(void)
 {
    return gLogTrace && MONGOC_TRACE_ENABLED;
 }
 
 void
-mongoc_log_trace_enable (void)
+mongoc_log_trace_enable(void)
 {
    /* Enable trace logging if-and-only-if tracing is enabled at configure-time,
     * otherwise tracing remains disabled.
@@ -81,14 +81,14 @@ mongoc_log_trace_enable (void)
 }
 
 void
-mongoc_log_trace_disable (void)
+mongoc_log_trace_disable(void)
 {
    gLogTrace = false;
 }
 
 /* just for testing */
 void
-_mongoc_log_get_handler (mongoc_log_func_t *log_func, void **user_data)
+_mongoc_log_get_handler(mongoc_log_func_t *log_func, void **user_data)
 {
    *log_func = gLogFunc;
    *user_data = gLogData;
@@ -96,36 +96,36 @@ _mongoc_log_get_handler (mongoc_log_func_t *log_func, void **user_data)
 
 
 void
-mongoc_log (mongoc_log_level_t log_level, const char *log_domain, const char *format, ...)
+mongoc_log(mongoc_log_level_t log_level, const char *log_domain, const char *format, ...)
 {
    va_list args;
    char *message;
    int stop_logging;
 
-   bson_once (&once, &_mongoc_ensure_mutex_once);
+   bson_once(&once, &_mongoc_ensure_mutex_once);
 
    stop_logging = !gLogFunc;
-   stop_logging = stop_logging || (log_level == MONGOC_LOG_LEVEL_TRACE && !_mongoc_log_trace_is_enabled ());
+   stop_logging = stop_logging || (log_level == MONGOC_LOG_LEVEL_TRACE && !_mongoc_log_trace_is_enabled());
    if (stop_logging) {
       return;
    }
 
-   BSON_ASSERT (format);
+   BSON_ASSERT(format);
 
-   va_start (args, format);
-   message = bson_strdupv_printf (format, args);
-   va_end (args);
+   va_start(args, format);
+   message = bson_strdupv_printf(format, args);
+   va_end(args);
 
-   bson_mutex_lock (&gLogMutex);
-   gLogFunc (log_level, log_domain, message, gLogData);
-   bson_mutex_unlock (&gLogMutex);
+   bson_mutex_lock(&gLogMutex);
+   gLogFunc(log_level, log_domain, message, gLogData);
+   bson_mutex_unlock(&gLogMutex);
 
-   bson_free (message);
+   bson_free(message);
 }
 
 
 const char *
-mongoc_log_level_str (mongoc_log_level_t log_level)
+mongoc_log_level_str(mongoc_log_level_t log_level)
 {
    switch (log_level) {
    case MONGOC_LOG_LEVEL_ERROR:
@@ -149,7 +149,7 @@ mongoc_log_level_str (mongoc_log_level_t log_level)
 
 
 void
-mongoc_log_default_handler (mongoc_log_level_t log_level, const char *log_domain, const char *message, void *user_data)
+mongoc_log_default_handler(mongoc_log_level_t log_level, const char *log_domain, const char *message, void *user_data)
 {
    struct timeval tv;
    struct tm tt;
@@ -158,22 +158,22 @@ mongoc_log_default_handler (mongoc_log_level_t log_level, const char *log_domain
    char nowstr[32];
    int pid;
 
-   BSON_UNUSED (user_data);
+   BSON_UNUSED(user_data);
 
-   bson_gettimeofday (&tv);
+   bson_gettimeofday(&tv);
    t = tv.tv_sec;
 
 #ifdef _WIN32
 #ifdef _MSC_VER
-   localtime_s (&tt, &t);
+   localtime_s(&tt, &t);
 #else
-   tt = *(localtime (&t));
+   tt = *(localtime(&t));
 #endif
 #else
-   localtime_r (&t, &tt);
+   localtime_r(&t, &tt);
 #endif
 
-   strftime (nowstr, sizeof nowstr, "%Y/%m/%d %H:%M:%S", &tt);
+   strftime(nowstr, sizeof nowstr, "%Y/%m/%d %H:%M:%S", &tt);
 
    switch (log_level) {
    case MONGOC_LOG_LEVEL_ERROR:
@@ -190,49 +190,49 @@ mongoc_log_default_handler (mongoc_log_level_t log_level, const char *log_domain
    }
 
 #ifdef __linux__
-   pid = syscall (SYS_gettid);
+   pid = syscall(SYS_gettid);
 #elif defined(_WIN32)
-   pid = (int) _getpid ();
+   pid = (int)_getpid();
 #elif defined(__FreeBSD__)
    long tid;
-   thr_self (&tid);
-   pid = (int) tid;
+   thr_self(&tid);
+   pid = (int)tid;
 #elif defined(__OpenBSD__)
-   pid = (int) getthrid ();
+   pid = (int)getthrid();
 #elif defined(__NetBSD__)
-   pid = (int) _lwp_self ();
+   pid = (int)_lwp_self();
 #elif defined(__APPLE__)
 #if MAC_OS_X_VERSION_MIN_REQUIRED < 1070
    // libc on macOS < 10.7 does not support `pthread_threadid_np`
-   mach_port_t tid = pthread_mach_thread_np (pthread_self ());
-   pid = (int) tid;
+   mach_port_t tid = pthread_mach_thread_np(pthread_self());
+   pid = (int)tid;
 #else
    uint64_t tid;
-   pthread_threadid_np (0, &tid);
-   pid = (int) tid;
+   pthread_threadid_np(0, &tid);
+   pid = (int)tid;
 #endif
 #else
-   pid = (int) getpid ();
+   pid = (int)getpid();
 #endif
 
-   fprintf (stream,
-            "%s.%04" PRId64 ": [%5d]: %8s: %12s: %s\n",
-            nowstr,
-            (int64_t) (tv.tv_usec / 1000),
-            pid,
-            mongoc_log_level_str (log_level),
-            log_domain,
-            message);
+   fprintf(stream,
+           "%s.%04" PRId64 ": [%5d]: %8s: %12s: %s\n",
+           nowstr,
+           (int64_t)(tv.tv_usec / 1000),
+           pid,
+           mongoc_log_level_str(log_level),
+           log_domain,
+           message);
 }
 
 void
-mongoc_log_trace_bytes (const char *domain, const uint8_t *_b, size_t _l)
+mongoc_log_trace_bytes(const char *domain, const uint8_t *_b, size_t _l)
 {
    STOP_LOGGING_CHECK;
 
    mcommon_string_append_t str, astr;
-   mcommon_string_new_as_append (&str);
-   mcommon_string_new_as_append (&astr);
+   mcommon_string_new_as_append(&str);
+   mcommon_string_new_as_append(&astr);
 
    size_t _i;
    for (_i = 0u; _i < _l; _i++) {
@@ -240,38 +240,38 @@ mongoc_log_trace_bytes (const char *domain, const uint8_t *_b, size_t _l)
       const size_t rem = _i % 16u;
 
       if (rem == 0u) {
-         mcommon_string_append_printf (&str, "%05zx: ", _i);
+         mcommon_string_append_printf(&str, "%05zx: ", _i);
       }
 
-      mcommon_string_append_printf (&str, " %02x", _v);
-      if (isprint (_v)) {
-         mcommon_string_append_printf (&astr, " %c", _v);
+      mcommon_string_append_printf(&str, " %02x", _v);
+      if (isprint(_v)) {
+         mcommon_string_append_printf(&astr, " %c", _v);
       } else {
-         mcommon_string_append (&astr, " .");
+         mcommon_string_append(&astr, " .");
       }
 
       if (rem == 15u) {
-         mongoc_log (
-            MONGOC_LOG_LEVEL_TRACE, domain, "%s %s", mcommon_str_from_append (&str), mcommon_str_from_append (&astr));
-         mcommon_string_from_append_clear (&str);
-         mcommon_string_from_append_clear (&astr);
+         mongoc_log(
+            MONGOC_LOG_LEVEL_TRACE, domain, "%s %s", mcommon_str_from_append(&str), mcommon_str_from_append(&astr));
+         mcommon_string_from_append_clear(&str);
+         mcommon_string_from_append_clear(&astr);
       } else if (rem == 7u) {
-         mcommon_string_append (&str, " ");
-         mcommon_string_append (&astr, " ");
+         mcommon_string_append(&str, " ");
+         mcommon_string_append(&astr, " ");
       }
    }
 
    if (_i != 16u) {
-      mongoc_log (
-         MONGOC_LOG_LEVEL_TRACE, domain, "%-56s %s", mcommon_str_from_append (&str), mcommon_str_from_append (&astr));
+      mongoc_log(
+         MONGOC_LOG_LEVEL_TRACE, domain, "%-56s %s", mcommon_str_from_append(&str), mcommon_str_from_append(&astr));
    }
 
-   mcommon_string_from_append_destroy (&str);
-   mcommon_string_from_append_destroy (&astr);
+   mcommon_string_from_append_destroy(&str);
+   mcommon_string_from_append_destroy(&astr);
 }
 
 void
-mongoc_log_trace_iovec (const char *domain, const mongoc_iovec_t *_iov, size_t _iovcnt)
+mongoc_log_trace_iovec(const char *domain, const mongoc_iovec_t *_iov, size_t _iovcnt)
 {
    const char *_b;
    unsigned _i = 0;
@@ -289,46 +289,43 @@ mongoc_log_trace_iovec (const char *domain, const mongoc_iovec_t *_iov, size_t _
    _i = 0;
 
    mcommon_string_append_t str, astr;
-   mcommon_string_new_as_append (&str);
-   mcommon_string_new_as_append (&astr);
+   mcommon_string_new_as_append(&str);
+   mcommon_string_new_as_append(&astr);
 
    for (_j = 0; _j < _iovcnt; _j++) {
-      _b = (char *) _iov[_j].iov_base;
+      _b = (char *)_iov[_j].iov_base;
       _l = _iov[_j].iov_len;
 
       for (_k = 0; _k < _l; _k++, _i++) {
          _v = *(_b + _k);
          if ((_i % 16) == 0) {
-            mcommon_string_append_printf (&str, "%05x: ", _i);
+            mcommon_string_append_printf(&str, "%05x: ", _i);
          }
 
-         mcommon_string_append_printf (&str, " %02x", _v);
-         if (isprint (_v)) {
-            mcommon_string_append_printf (&astr, " %c", _v);
+         mcommon_string_append_printf(&str, " %02x", _v);
+         if (isprint(_v)) {
+            mcommon_string_append_printf(&astr, " %c", _v);
          } else {
-            mcommon_string_append (&astr, " .");
+            mcommon_string_append(&astr, " .");
          }
 
          if ((_i % 16) == 15) {
-            mongoc_log (MONGOC_LOG_LEVEL_TRACE,
-                        domain,
-                        "%s %s",
-                        mcommon_str_from_append (&str),
-                        mcommon_str_from_append (&astr));
-            mcommon_string_from_append_clear (&str);
-            mcommon_string_from_append_clear (&astr);
+            mongoc_log(
+               MONGOC_LOG_LEVEL_TRACE, domain, "%s %s", mcommon_str_from_append(&str), mcommon_str_from_append(&astr));
+            mcommon_string_from_append_clear(&str);
+            mcommon_string_from_append_clear(&astr);
          } else if ((_i % 16) == 7) {
-            mcommon_string_append (&str, " ");
-            mcommon_string_append (&astr, " ");
+            mcommon_string_append(&str, " ");
+            mcommon_string_append(&astr, " ");
          }
       }
    }
 
    if (_i != 16) {
-      mongoc_log (
-         MONGOC_LOG_LEVEL_TRACE, domain, "%-56s %s", mcommon_str_from_append (&str), mcommon_str_from_append (&astr));
+      mongoc_log(
+         MONGOC_LOG_LEVEL_TRACE, domain, "%-56s %s", mcommon_str_from_append(&str), mcommon_str_from_append(&astr));
    }
 
-   mcommon_string_from_append_destroy (&str);
-   mcommon_string_from_append_destroy (&astr);
+   mcommon_string_from_append_destroy(&str);
+   mcommon_string_from_append_destroy(&astr);
 }
