@@ -1,5 +1,5 @@
 /*
- * Copyright 2017 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,17 +14,16 @@
  * limitations under the License.
  */
 
-#include "mongoc-prelude.h"
+#include <mongoc/mongoc-prelude.h>
 
 #ifndef MONGOC_MACROS_H
 #define MONGOC_MACROS_H
 
 /* Decorate public functions:
- * - if MONGOC_STATIC, we're compiling a program that uses libmongoc as
- *   a static library, don't decorate functions
- * - else if MONGOC_COMPILATION, we're compiling a static or shared libmongoc,
- *   mark public functions for export from the shared lib (which has no effect
- *   on the static lib)
+ * - if MONGOC_STATIC, we're compiling a static libmongoc or a program
+ *   that uses libmongoc as a static library. Don't decorate functions
+ * - else if MONGOC_COMPILATION, we're compiling a shared libmongoc,
+ *   mark public functions for export from the shared lib.
  * - else, we're compiling a program that uses libmongoc as a shared library,
  *   mark public functions as DLL imports for Microsoft Visual C.
  */
@@ -49,7 +48,7 @@
 #ifdef MONGOC_STATIC
 #define MONGOC_API
 #elif defined(MONGOC_COMPILATION)
-#define MONGOC_API __attribute__ ((visibility ("default")))
+#define MONGOC_API __attribute__((visibility("default")))
 #else
 #define MONGOC_API
 #endif
