@@ -21,13 +21,17 @@
 #define MONGOC_RAND_PRIVATE_H
 
 
+#include <mongoc/mongoc-rand.h> // IWYU pragma: export
+
+//
+
 #include <bson/bson.h>
 
 
 BSON_BEGIN_DECLS
 
 int
-_mongoc_rand_bytes (uint8_t *buf, int num);
+_mongoc_rand_bytes(uint8_t *buf, int num);
 
 BSON_END_DECLS
 
