@@ -19,15 +19,21 @@
 #ifndef MONGOC_STREAM_TLS_PRIVATE_H
 #define MONGOC_STREAM_TLS_PRIVATE_H
 
-#include <bson/bson.h>
+#include <mongoc/mongoc-stream-tls.h> // IWYU pragma: export
+
+//
 
 #include <mongoc/mongoc-ssl.h>
 #include <mongoc/mongoc-stream.h>
 
+#include <bson/bson.h>
+
 #ifdef MONGOC_ENABLE_SSL_OPENSSL
 #include <openssl/ssl.h>
 #endif
 
+#include <mongoc/mongoc-shared-private.h>
+
 BSON_BEGIN_DECLS
 
 /**
@@ -43,17 +49,23 @@ struct _mongoc_stream_tls_t {
    void *ctx;                    /* TLS lib specific configuration or wrappers */
    int64_t timeout_msec;
    mongoc_ssl_opt_t ssl_opts;
-   bool (*handshake) (mongoc_stream_t *stream, const char *host, int *events /* OUT*/, bson_error_t *error);
+   bool (*handshake)(mongoc_stream_t *stream, const char *host, int *events /* OUT*/, bson_error_t *error);
 };
 
 #if defined(MONGOC_ENABLE_SSL_OPENSSL) && OPENSSL_VERSION_NUMBER >= 0x10100000L
-MONGOC_EXPORT (mongoc_stream_t *)
-mongoc_stream_tls_new_with_hostname_and_openssl_context (mongoc_stream_t *base_stream,
-                                                         const char *host,
-                                                         mongoc_ssl_opt_t *opt,
-                                                         int client,
-                                                         SSL_CTX *ssl_ctx) BSON_GNUC_WARN_UNUSED_RESULT;
-#endif
+MONGOC_EXPORT(mongoc_stream_t *)
+mongoc_stream_tls_new_with_hostname_and_openssl_context(mongoc_stream_t *base_stream,
+                                                        const char *host,
+                                                        mongoc_ssl_opt_t *opt,
+                                                        int client,
+                                                        SSL_CTX *ssl_ctx) BSON_GNUC_WARN_UNUSED_RESULT;
+#elif defined(MONGOC_ENABLE_SSL_SECURE_CHANNEL)
+mongoc_stream_t *
+mongoc_stream_tls_new_with_secure_channel_cred(mongoc_stream_t *base_stream,
+                                               const char *host,
+                                               mongoc_ssl_opt_t *opt,
+                                               mongoc_shared_ptr secure_channel_cred_ptr) BSON_GNUC_WARN_UNUSED_RESULT;
+#endif // MONGOC_ENABLE_SSL_SECURE_CHANNEL
 
 BSON_END_DECLS
 
