@@ -20,12 +20,17 @@
 #define MONGOC_STREAM_TLS_SECURE_TRANSPORT_PRIVATE_H
 
 #ifdef MONGOC_ENABLE_SSL_SECURE_TRANSPORT
+
+#include <mongoc/mongoc-stream-tls-secure-transport.h> // IWYU pragma: export
+
+//
+
+#include <common-macros-private.h>
+
 #include <bson/bson.h>
 
 #include <Security/Security.h>
 
-#include <common-macros-private.h>
-
 BSON_BEGIN_DECLS
 
 // CDRIVER-2722: Secure Transport is deprecated on MacOS.
