@@ -1,5 +1,5 @@
 /*
- * Copyright 2024-present MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,11 +17,12 @@
 #ifndef MONGOC_UTHASH_H
 #define MONGOC_UTHASH_H
 
-#include <mongoc-prelude.h>
+#include <mongoc/mongoc-prelude.h>
+
 #include <bson/bson.h>
 
-#define uthash_malloc(sz) bson_malloc (sz)
-#define uthash_free(ptr, sz) bson_free (ptr)
+#define uthash_malloc(sz) bson_malloc(sz)
+#define uthash_free(ptr, sz) bson_free(ptr)
 
 #include <uthash-2.3.0/uthash.h>
 
